@@ -12,7 +12,7 @@
 
 #include "iostream.hpp"
 
-namespace acommon {
+namespace aspell {
   unsigned int linenumber = 0 ;
 
   bool getdata_pair(IStream & in, DataPair & d, String & buf)
@@ -22,7 +22,7 @@ namespace acommon {
     // get first non blank line and count all read ones
     do {
       buf.clear();
-      buf.append('\0'); // to avoid some special cases
+      buf.append('\0'); // to avoid some special cases when scanning backward
       if (!in.append_line(buf)) return false;
       d.line_num++;
       p = buf.mstr() + 1;
@@ -86,7 +86,14 @@ namespace acommon {
 
   bool escape(char * dest, const char * src, size_t limit, const char * others)
   {
+    const char * begin = src;
     const char * end = dest + limit;
+    if (asc_isspace(*src)) {
+      if (dest == end) return false;
+      *dest++ = '\\';
+      if (dest == end) return false;
+      *dest++ = *src++;
+    }
     while (*src) {
       if (dest == end) return false;
       switch (*src) {
@@ -104,6 +111,12 @@ namespace acommon {
       ++src;
       ++dest;
     }
+    if (src > begin + 1 && asc_isspace(src[-1])) {
+      --dest;
+      *dest++ = '\\';
+      if (dest == end) return false;
+      *dest++ = src[-1];
+    }
     *dest = '\0';
     return true;
   }
@@ -113,6 +126,11 @@ namespace acommon {
     for (; *str; str++) *str = asc_tolower(*str);
   }
 
+  void to_lower(String & res, const char * str)
+  {
+    for (; *str; str++) res += asc_tolower(*str);
+  }
+
   bool split(DataPair & d)
   {
     char * p   = d.value;
@@ -137,7 +155,7 @@ namespace acommon {
   {
     const char * s = str;
     while (*s == ' ' || *s == '\t') ++s;
-    size_t l = str.size() - (s - str);
+    size_t l = str.size() - (s - str.str());
     buf.assign(s, l);
     d.value.str  = buf.mstr();
     d.value.size = l;
@@ -163,13 +181,22 @@ namespace acommon {
     return p;
   }
 
+  char * remove_comments(char * p)
+  {
+    char * b = p;
+    while (*p && *p != '#') ++p;
+    if (*p == '#') {--p; while (p >= b && asc_isspace(*p)) --p; ++p;}
+    *p = '\0';
+    return p;
+  }
+
   void remove_comments(String & buf)
   {
-    buf.ensure_null_end();
-    char * p = buf.data();
+    char * p = buf.mstr();
+    char * b = p;
     while (*p && *p != '#') ++p;
-    if (*p == '#') {--p; while (p >= buf.data() && asc_isspace(*p)) --p; ++p;}
-    buf.resize(p - buf.data());
+    if (*p == '#') {--p; while (p >= b && asc_isspace(*p)) --p; ++p;}
+    buf.resize(p - b);
   }
 
 }
