@@ -1,4 +1,4 @@
-// Copyright (c) 2001,2011
+// Copyright (c) 2001
 // Kevin Atkinson
 //
 // Permission to use, copy, modify, distribute and sell this software
@@ -43,10 +43,11 @@
 #include <cstdlib>
 #include <new>
 
+#include "settings.h"
 #include "hash.hpp"
 #include "block_slist-t.hpp"
 
-namespace acommon {
+namespace aspell {
   
   static const unsigned int primes[] =
   {
@@ -84,7 +85,7 @@ namespace acommon {
   }
 
   template <class P>
-  std::pair<typename HashTable<P>::iterator,bool> HashTable<P>::insert(const Value & to_insert)
+  std::pair<TYPENAME HashTable<P>::iterator,bool> HashTable<P>::insert(const Value & to_insert)
   {
     bool have;
     iterator put_me_here = find_i(parms_.key(to_insert), have);
@@ -107,7 +108,7 @@ namespace acommon {
   template <class P>
   void HashTable<P>::erase(iterator to_erase) 
   {
-    (*to_erase.n)->data.~Value();
+    NodePool::del_node((*to_erase.n)->data);
     Node * tmp = *to_erase.n;
     *to_erase.n = (*to_erase.n)->next;
     node_pool_.remove_node(tmp);
@@ -123,7 +124,7 @@ namespace acommon {
     Node * n = *first;
     while (n != 0 && parms_.equal(parms_.key(n->data), k)) {
       Node * tmp = n;
-      n->data.~Value();
+      NodePool::del_node(n);
       n = n->next;
       node_pool_.remove_node(tmp);
       ++num_erased;
@@ -152,7 +153,7 @@ namespace acommon {
   }
 
   template <class P>
-  std::pair<typename HashTable<P>::iterator, typename HashTable<P>::iterator>
+  std::pair<TYPENAME HashTable<P>::iterator, TYPENAME HashTable<P>::iterator>
   HashTable<P>::equal_range_i(const Key & to_find, int & c)
   {
     c = 0;
@@ -177,7 +178,7 @@ namespace acommon {
     for (Node * * i = table_; i != table_end_; ++i) {
       Node * n = *i;
       while (n != 0) {
-	n->data.~Value();
+        NodePool::del_node(n);
 	n = n->next;
       }
     }
