@@ -23,6 +23,7 @@
 #define MAXAFFIXES      256
 #define MAXWORDLEN      255
 #define XPRODUCT        (1 << 0)
+#define CIRCUMFIX       (1 << 1)
 
 #define MAXLNLEN        1024
 
@@ -69,6 +70,9 @@ namespace sp {
 
     const char * affix_file;
 
+  public: // but don't use
+    bool                two_fold_suffix;
+
   public:
  
     AffixMgr(const LangImpl * l);
@@ -82,7 +86,7 @@ namespace sp {
     bool prefix_check(const LookupInfo &, ParmString, IntrCheckInfo &, GuessInfo *,
                       bool cross = true) const;
     bool suffix_check(const LookupInfo &, ParmString, IntrCheckInfo &, GuessInfo *,
-                      int sfxopts, AffEntry* ppfx) const;
+                      const PfxEntry * ppfx = NULL, const SfxEntry * psfx = NULL) const;
 
     void munch(ParmString word, GuessInfo *, bool cross = true) const;
 
